gmp: Library for arbitrary precision arithmetic
===============================================

Description
-----------

GMP is a free library for arbitrary precision arithmetic, operating on
signed integers, rational numbers, and floating-point numbers. There is
no practical limit to the precision except the ones implied by the
available memory in the machine GMP runs on. GMP has a rich set of
functions, and the functions have a regular interface.

License
-------

-  LGPL V3


Upstream Contact
----------------

-  http://gmplib.org
